summaryrefslogtreecommitdiff
path: root/exercises/18_iterators/iterators2.rs
diff options
context:
space:
mode:
Diffstat (limited to 'exercises/18_iterators/iterators2.rs')
-rw-r--r--exercises/18_iterators/iterators2.rs40
1 files changed, 17 insertions, 23 deletions
diff --git a/exercises/18_iterators/iterators2.rs b/exercises/18_iterators/iterators2.rs
index dda82a0..5903e65 100644
--- a/exercises/18_iterators/iterators2.rs
+++ b/exercises/18_iterators/iterators2.rs
@@ -1,38 +1,32 @@
-// iterators2.rs
-//
// In this exercise, you'll learn some of the unique advantages that iterators
-// can offer. Follow the steps to complete the exercise.
-//
-// Execute `rustlings hint iterators2` or use the `hint` watch subcommand for a
-// hint.
+// can offer.
-// I AM NOT DONE
-
-// Step 1.
-// Complete the `capitalize_first` function.
+// TODO: Complete the `capitalize_first` function.
// "hello" -> "Hello"
-pub fn capitalize_first(input: &str) -> String {
- let mut c = input.chars();
- match c.next() {
+fn capitalize_first(input: &str) -> String {
+ let mut chars = input.chars();
+ match chars.next() {
None => String::new(),
- Some(first) => ???,
+ Some(first) => todo!(),
}
}
// Step 2.
// Apply the `capitalize_first` function to a slice of string slices.
// Return a vector of strings.
// ["hello", "world"] -> ["Hello", "World"]
-pub fn capitalize_words_vector(words: &[&str]) -> Vec<String> {
- vec![]
+fn capitalize_words_vector(words: &[&str]) -> Vec<String> {
+ // ???
}
// Step 3.
// Apply the `capitalize_first` function again to a slice of string slices.
// Return a single string.
// ["hello", " ", "world"] -> "Hello World"
-pub fn capitalize_words_string(words: &[&str]) -> String {
- String::new()
+fn capitalize_words_string(words: &[&str]) -> String {
+ // ???
+}
+
+fn main() {
+ // You can optionally experiment here.
}
#[cfg(test)]
@@ -1,38 +1,32 @@
}
}
-// Step 2.
-// Apply the `capitalize_first` function to a slice of string slices.
+// TODO: Apply the `capitalize_first` function to a slice of string slices.
// Return a vector of strings.
// ["hello", "world"] -> ["Hello", "World"]
@@ -1,38 +1,32 @@
}
-// Step 3.
-// Apply the `capitalize_first` function again to a slice of string slices.
-// Return a single string.
+// TODO: Apply the `capitalize_first` function again to a slice of string
+// slices. Return a single string.
// ["hello", " ", "world"] -> "Hello World"